/*
 * Copyright (C) 2018 Pedro Perez
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package edu.uoc.sporttrack;

import android.content.Context;
import android.content.Intent;
import android.support.annotation.NonNull;
import android.support.design.widget.NavigationView;
import android.support.v4.view.GravityCompat;
import android.support.v4.widget.DrawerLayout;
import android.support.v7.app.ActionBarDrawerToggle;
import android.support.v7.widget.Toolbar;
import android.view.MenuItem;
import android.view.View;
import android.view.inputmethod.InputMethodManager;
import android.widget.FrameLayout;

public class BaseDrawerActivity extends BaseActivity implements NavigationView.OnNavigationItemSelectedListener
{
    protected DrawerLayout fullLayout;
    protected FrameLayout frameLayout;

    @Override
    public void setContentView(int layoutResID)
    {
        fullLayout = (DrawerLayout) getLayoutInflater().inflate(R.layout.nav_drawer_base, null);
        frameLayout = fullLayout.findViewById(R.id.drawer_frame);

        getLayoutInflater().inflate(layoutResID, frameLayout, true);

        super.setContentView(fullLayout);
    }

    /**
     * Called when an item in the navigation menu is selected.
     */
    @Override
    public boolean onNavigationItemSelected(@NonNull MenuItem item)
    {
        Intent intent;

        // Handles navigation view item clicks.
        switch (item.getItemId())
        {
            case R.id.nav_home:
                if (!(this instanceof MainActivity))
                {
                    intent = new Intent(this, MainActivity.class);
                    startActivity(intent);
                }
                break;

            case R.id.nav_routines:
                if (!(this instanceof RoutineActivity))
                {
                    intent = new Intent(this, RoutineActivity.class);
                    startActivity(intent);
                }
                break;

            case R.id.nav_exercises:
                if (!(this instanceof BodypartActivity))
                {
                    intent = new Intent(this, BodypartActivity.class);
                    startActivity(intent);
                }
                break;

            case R.id.nav_history:
                if (!(this instanceof HistoryActivity))
                {
                    intent = new Intent(this, HistoryActivity.class);
                    startActivity(intent);
                }
                break;

            case R.id.nav_profile:
                if (!(this instanceof ProfileActivity))
                {
                    intent = new Intent(this, ProfileActivity.class);
                    startActivity(intent);
                }
                break;

            case R.id.nav_settings:
                if (!(this instanceof SettingsActivity))
                {
                    intent = new Intent(this, SettingsActivity.class);
                    startActivity(intent);
                }
                break;

            default:
                break;
        }

        DrawerLayout drawer = findViewById(R.id.drawer_layout);
        drawer.closeDrawer(GravityCompat.START);
        return true;
    }

    /**
     * Called when the activity has detected the user's press of the img_back key.
     */
    @Override
    public void onBackPressed()
    {
        DrawerLayout drawer = findViewById(R.id.drawer_layout);
        if (drawer.isDrawerOpen(GravityCompat.START))
        {
            drawer.closeDrawer(GravityCompat.START);
        }
        else
        {
            super.onBackPressed();
        }
    }

    /**
     * Renders navigation drawer
     */
    public void renderNavigationDrawer(Toolbar toolbar)
    {
        DrawerLayout drawer = findViewById(R.id.drawer_layout);
        ActionBarDrawerToggle toggle = new ActionBarDrawerToggle(this, drawer, toolbar, R.string.navigation_drawer_open,
                                                                 R.string.navigation_drawer_close);
        drawer.addDrawerListener(toggle);
        toggle.syncState();

        NavigationView navigationView = findViewById(R.id.nav_view);
        navigationView.setNavigationItemSelectedListener(this);
    }

    /**
     * Clears focus and hides soft keyboard
     */
    public void clearFocus(View... views)
    {
        for (View view : views)
        {
            if (view != null)
            {
                view.clearFocus();
            }
        }

        InputMethodManager imm = (InputMethodManager) getSystemService(Context.INPUT_METHOD_SERVICE);
        if (imm != null && views[0] != null)
        {
            imm.hideSoftInputFromWindow(views[0].getWindowToken(), 0);
        }
    }
}
