/*
 * Copyright (C) 2018 Pedro Perez
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package edu.uoc.sporttrack;

import android.content.Intent;
import android.os.Bundle;
import android.os.CountDownTimer;

import com.github.lzyzsd.circleprogress.DonutProgress;

import edu.uoc.sporttrack.model.LogSet;
import edu.uoc.sporttrack.utils.Utils;

public class CounterdownActivity extends BaseActivity
{
    private LogSet logSet;
    DonutProgress counterdown;

    @Override
    protected void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);

        // Retrieves the content view that renders the activity.
        setContentView(R.layout.counterdown_activity);

        // Retrieves data from intent
        Bundle bundle = getIntent().getBundleExtra(Utils.BUNDLE);
        if (bundle != null)
        {
            logSet = bundle.getParcelable(Utils.LOGSET);
        }

        // Renders the toolbar in activity
        renderToolbar(true, getResources().getString(R.string.exercise_title_detail));

        setupInitialValues();
    }

    /**
     * Sets up initial values.
     */
    private void setupInitialValues()
    {
        if (logSet != null)
        {
            counterdown = findViewById(R.id.counterdown);

            final long totalMillis = logSet.getRest() * 1000;

            new CountDownTimer(totalMillis, 1000)
            {
                @Override
                public void onTick(long millisUntilFinished)
                {
                    String progress = String.valueOf((millisUntilFinished * 100) / totalMillis);
                    counterdown.setText(String.valueOf(millisUntilFinished / 1000));
                    counterdown.setDonut_progress(progress);
                }

                @Override
                public void onFinish()
                {
                    // Finishes activity and sends OK code to waiting activity
                    Intent intent = new Intent();
                    setResult(Utils.RESULT_OK, intent);
                    finish();
                }
            }.start();
        }
    }
}
