/*
 * Copyright (C) 2018 Pedro Perez
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package edu.uoc.sporttrack;

import android.os.Bundle;
import android.widget.TextView;

import edu.uoc.sporttrack.model.Bodypart;
import edu.uoc.sporttrack.model.Exercise;
import edu.uoc.sporttrack.utils.Utils;

public class ExerciseDetailActivity extends BaseActivity
{
    private Exercise exercise;
    private Bodypart bodypart;

    @Override
    protected void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);

        // Retrieves the content view that renders the activity.
        setContentView(R.layout.exercise_detail_activity);

        // Retrieves data from intent
        Bundle bundle = getIntent().getBundleExtra(Utils.BUNDLE);
        if (bundle != null)
        {
            bodypart = bundle.getParcelable(Utils.BODYPART);
            exercise = bundle.getParcelable(Utils.EXERCISE);
        }

        // Renders the toolbar in activity
        renderToolbar(true, exercise != null ? exercise.getName() : getResources().getString(R.string.exercise_title_detail));

        setupInitialValues();
    }

    /**
     * Sets up initial values.
     */
    private void setupInitialValues()
    {
        TextView desc = findViewById(R.id.exerciseDescription);
        desc.setText(exercise != null ? exercise.getDescription() : "");

        TextView group = findViewById(R.id.exerciseBodypart);
        group.setText(bodypart != null ? bodypart.getName() : "");
    }
}
