/*
 * Copyright (C) 2018 Pedro Perez
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package edu.uoc.sporttrack;

import android.content.Intent;
import android.os.Bundle;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import edu.uoc.sporttrack.adapter.RecyclerAdapter;
import edu.uoc.sporttrack.database.SessionDatabaseHelper;
import edu.uoc.sporttrack.model.Itemizable;
import edu.uoc.sporttrack.model.Session;
import edu.uoc.sporttrack.utils.Utils;

public class HistoryDayActivity extends BaseDrawerActivity
{
    private Date day;
    private SessionDatabaseHelper db;

    @Override
    protected void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);

        // Retrieves the content view that renders the activity.
        setContentView(R.layout.history_day_activity);

        // Retrieves data from intent
        Bundle bundle = getIntent().getBundleExtra(Utils.BUNDLE);
        if (bundle != null)
        {
            day = (Date) bundle.getSerializable(Utils.LOGDAY);
        }

        // Renders the toolbar in activity
        renderToolbar(true, getResources().getString(R.string.history_logs) + " " + (day != null ? Utils.formatDate(day, "dd/MM/yyyy") : ""));

        // Creates database helper
        db = new SessionDatabaseHelper(this);

        displayLogs();
    }

    /**
     * Lists all logs for received day
     */
    private void displayLogs()
    {
        if (day != null)
        {
            List<Itemizable> items = new ArrayList<>();
            items.addAll(db.getSessions(day));

            RecyclerView recyclerView = findViewById(R.id.historySessionsRecyclerView);

            // Populates recycler view with items from cursor
            recyclerView.setLayoutManager(new LinearLayoutManager(this));

            // Creates adapter for recycler view
            RecyclerAdapter logsAdapter = new RecyclerAdapter(this, R.layout.row_history, items, this, true);
            recyclerView.setAdapter(logsAdapter);
        }
    }

    /**
     * Callback method when a item in list view is clicked.
     * See {@link edu.uoc.sporttrack.adapter.OnItemActionListener#onItemSelect(Itemizable)}
     */
    @Override
    public void onItemSelect(Itemizable itemizable)
    {
        Session session = (Session) itemizable;

        // Starts activity and waits for response
        Bundle bundle = new Bundle();
        bundle.putParcelable(Utils.SESSION, session);
        Intent intent = new Intent(getApplicationContext(), HistoryDayMapActivity.class);

        if (session.getIdSport() == Utils.SPORT_WORKOUT)
        {
            intent = new Intent(getApplicationContext(), HistoryDayWorkoutActivity.class);
        }

        intent.putExtra(Utils.BUNDLE, bundle);
        startActivity(intent);
    }
}
