/*
 * Copyright (C) 2018 Pedro Perez
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package edu.uoc.sporttrack;

import android.content.Intent;
import android.os.Bundle;
import android.support.v7.widget.SwitchCompat;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.EditText;
import android.widget.Toast;

import edu.uoc.sporttrack.database.RoutineDatabaseHelper;
import edu.uoc.sporttrack.model.Routine;
import edu.uoc.sporttrack.utils.Utils;

public class RoutineEditActivity extends BaseActivity
{
    private RoutineDatabaseHelper db;
    private EditText nameEditText, descEditText;
    private SwitchCompat current;
    private Routine routine;

    @Override
    protected void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);

        // Retrieves the content view that renders the activity.
        setContentView(R.layout.routine_add_activity);

        // Retrieves data from intent
        Bundle bundle = getIntent().getBundleExtra(Utils.BUNDLE);
        if (bundle != null)
        {
            routine = bundle.getParcelable(Utils.ROUTINE);
        }

        // Renders the toolbar in activity
        renderToolbar(true, routine != null ? R.string.routine_title_edit : R.string.routine_title_add);

        // Creates database helper
        db = new RoutineDatabaseHelper(this);

        setupInitialValues();
    }

    /**
     * Sets up the action bar.
     */
    @Override
    public boolean onCreateOptionsMenu(Menu menu)
    {
        // Inflates the menu, adding items to the action bar
        getMenuInflater().inflate(R.menu.toolbar_save, menu);
        return true;
    }

    /**
     * Called whenever an item in action bar is selected.
     */
    @Override
    public boolean onOptionsItemSelected(MenuItem item)
    {
        switch (item.getItemId())
        {
            // When clicking on saving an routine
            case R.id.action_save:

                nameEditText = findViewById(R.id.routineName);
                descEditText = findViewById(R.id.routineDesc);
                current = findViewById(R.id.routineCurrent);

                // If validations are ok, day is saved
                if (saveRoutine())
                {
                    // Finishes activity and sends OK code to waiting activity
                    Intent intent = new Intent();
                    setResult(Utils.RESULT_OK, intent);
                    finish();
                }
                return true;

            default:
                return super.onOptionsItemSelected(item);
        }
    }

    /**
     * Sets up initial values.
     */
    private void setupInitialValues()
    {
        if (routine != null)
        {
            nameEditText = findViewById(R.id.routineName);
            nameEditText.setText(routine.getName());

            descEditText = findViewById(R.id.routineDesc);
            descEditText.setText(routine.getDescription());

            current = findViewById(R.id.routineCurrent);
            current.setChecked(routine.isCurrent());
        }
    }

    /**
     * Validates and saves routine in database and returns true if ok
     */
    private boolean saveRoutine()
    {
        if (validateMandatoryFields(nameEditText))
        {
            if (routine == null)
            {
                routine = new Routine();
            }

            // Setting valid values to routine object
            routine.setName(nameEditText.getText().toString().trim());
            routine.setCurrent(current.isChecked());
            if (!descEditText.getText().toString().trim().isEmpty())
            {
                routine.setDescription(descEditText.getText().toString().trim());
            }

            if (db.saveOrUpdate(routine) > 0)
            {
                return true;
            }

            Toast.makeText(this, R.string.err_routine_saved, Toast.LENGTH_SHORT).show();
        }
        return false;
    }

}
