/*
 * Copyright (C) 2018 Pedro Perez
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package edu.uoc.sporttrack;

import android.content.Intent;
import android.os.Bundle;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.widget.Toast;

import java.util.ArrayList;
import java.util.List;

import edu.uoc.sporttrack.adapter.OnItemActionListener;
import edu.uoc.sporttrack.adapter.RecyclerAdapter;
import edu.uoc.sporttrack.database.DayDatabaseHelper;
import edu.uoc.sporttrack.database.SessionDatabaseHelper;
import edu.uoc.sporttrack.model.Day;
import edu.uoc.sporttrack.model.Itemizable;
import edu.uoc.sporttrack.model.Routine;
import edu.uoc.sporttrack.utils.Utils;

public class SessionCurrentRoutineActivity extends BaseActivity
{
    private Routine routine;
    private DayDatabaseHelper dayDB;
    private long sport;

    @Override
    protected void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);

        // Retrieves the content view that renders the activity.
        setContentView(R.layout.session_current_routine_activity);

        // Retrieves data from intent
        Bundle bundle = getIntent().getBundleExtra(Utils.BUNDLE);
        if (bundle != null)
        {
            sport = getIntent().getBundleExtra(Utils.BUNDLE).getLong(Utils.SPORT);
            routine = bundle.getParcelable(Utils.ROUTINE);
        }

        // Renders the toolbar in activity
        renderToolbar(true, routine != null ? routine.getName() : getResources().getString(R.string.routine_current));

        // Creates database helper
        dayDB = new DayDatabaseHelper(this);
        SessionDatabaseHelper sessionDB = new SessionDatabaseHelper(this);

        // Checks and closes previous active sessions
        sessionDB.closeActiveWorkoutSessions();

        // Deletes all inactive logs plans with no sets
        sessionDB.deleteInactiveLogPlans();

        // Lists all routine days for selected routine
        displayRoutineDays();
    }

    /**
     * Lists all routine days in recycler view for received routine
     */
    private void displayRoutineDays()
    {
        // Populates recycler view with items from cursor
        RecyclerView recyclerView = findViewById(R.id.currentRoutineRecyclerView);
        recyclerView.setLayoutManager(new LinearLayoutManager(this));

        List<Day> days = dayDB.getAll(routine.getId());

        // Creates adapter for recycler view
        List<Itemizable> items = new ArrayList<>();
        RecyclerAdapter adapter = new RecyclerAdapter(this, R.layout.row_general, items, this, true);
        items.addAll(days);
        recyclerView.setAdapter(adapter);

        if (days.size() == 0)
        {
            Toast.makeText(this, R.string.err_session_no_days, Toast.LENGTH_SHORT).show();
        }
    }

    /**
     * Callback method to get result from other activity.
     */
    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data)
    {
        super.onActivityResult(requestCode, resultCode, data);
        displayRoutineDays();
    }

    /**
     * Callback method when a item in list view is clicked.
     * See {@link OnItemActionListener#onItemSelect(Itemizable)}
     */
    @Override
    public void onItemSelect(Itemizable itemizable)
    {
        Day day = (Day) itemizable;
        if (day.getNumPlans() > 0)
        {
            // Starts activity and waits for response
            Bundle bundle = new Bundle();
            bundle.putParcelable(Utils.DAY, (Day) itemizable);
            bundle.putLong(Utils.SPORT, sport);
            Intent intent = new Intent(getApplicationContext(), SessionDayActivity.class);
            intent.putExtra(Utils.BUNDLE, bundle);
            startActivityForResult(intent, Utils.CODE_SELECT_WORKOUT);
        }
        else
        {
            Toast.makeText(this, R.string.err_session_no_plans, Toast.LENGTH_SHORT).show();
        }
    }

}
