/*
 * Copyright (C) 2018 Pedro Perez
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package edu.uoc.sporttrack;

import android.content.Intent;
import android.os.Bundle;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.support.v7.widget.Toolbar;

import java.util.ArrayList;
import java.util.List;

import edu.uoc.sporttrack.adapter.OnItemActionListener;
import edu.uoc.sporttrack.adapter.RecyclerAdapter;
import edu.uoc.sporttrack.model.Itemizable;
import edu.uoc.sporttrack.model.Sport;
import edu.uoc.sporttrack.utils.Utils;

public class SportActivity extends BaseDrawerActivity
{
    private int[] sportImages = new int[]{R.drawable.sport_cycling, R.drawable.sport_moutbiking, R.drawable.sport_rowing, R.drawable.sport_running,
                                          R.drawable.sport_skiing, R.drawable.sport_timed, R.drawable.sport_workout, R.drawable.sport_noactivity};
    private int[] sportIcons = new int[]{R.drawable.btn_cycling, R.drawable.btn_moutbiking, R.drawable.btn_rowing, R.drawable.btn_running,
                                         R.drawable.btn_skiing, R.drawable.btn_timed, R.drawable.btn_workout, R.drawable.ic_sporttrack};

    @Override
    protected void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);

        // Retrieves the content view that renders the activity.
        setContentView(R.layout.sport_activity);

        // Renders the toolbar in activity
        Toolbar toolbar = renderToolbar(false, R.string.sport_title_select);

        displaySports();
    }

    /**
     * Populates view list with items
     */
    private void displaySports()
    {
        // Gets sports array from resources
        String[] sportNames = getResources().getStringArray(R.array.sports);

        // Creates adapter for recycler view
        List<Itemizable> items = new ArrayList<>();

        for (int i = 0; i < sportNames.length; i++)
        {
            Sport item = new Sport();
            item.setName(sportNames[i]);
            item.setImage(sportImages[i]);
            item.setIcon(sportIcons[i]);
            item.setId(i + 1);
            items.add(item);
        }

        Sport noActivity = new Sport();
        noActivity.setId(-1);
        noActivity.setImage(R.drawable.sport_noactivity);
        noActivity.setName(getResources().getString(R.string.sport_no_activity));
        items.add(noActivity);

        RecyclerAdapter adapter = new RecyclerAdapter(this, R.layout.row_images, items, this, true);

        // Populates recycler view with items
        RecyclerView recyclerView = findViewById(R.id.sportsRecyclerView);
        recyclerView.setLayoutManager(new LinearLayoutManager(this));
        recyclerView.setAdapter(adapter);
    }

    /**
     * Callback method when a item in list view is clicked.
     * See {@link OnItemActionListener#onItemSelect(Itemizable)}
     */
    @Override
    public void onItemSelect(Itemizable item)
    {
        if (item != null && item.getId() == -1)
        {
            item = null;
        }

        // Finishes activity and sends OK code to waiting activity
        Intent intent = new Intent();
        intent.putExtra(Utils.SPORT, (Sport) item);
        setResult(Utils.RESULT_OK, intent);
        finish();
    }

}
