/*
 * Copyright (C) 2018 Pedro Perez
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package edu.uoc.sporttrack;

import android.content.Intent;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.EditText;
import android.widget.TextView;

import edu.uoc.sporttrack.database.SessionDatabaseHelper;
import edu.uoc.sporttrack.database.SettingsDatabaseHelper;
import edu.uoc.sporttrack.model.Session;
import edu.uoc.sporttrack.model.Settings;
import edu.uoc.sporttrack.utils.Utils;

public class TimedDetailActivity extends BaseActivity
{
    private SessionDatabaseHelper db;
    private Session session = null;
    private EditText distance, speed;

    @Override
    protected void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);

        // Retrieves the content view that renders the activity.
        setContentView(R.layout.timed_detail_activity);

        // Retrieves data from intent
        Bundle bundle = getIntent().getBundleExtra(Utils.BUNDLE);
        if (bundle != null)
        {
            session = bundle.getParcelable(Utils.SESSION);
        }

        // Renders the toolbar in activity
        renderToolbar(true, getResources().getString(R.string.summary_title_detail));

        // Creates database helper
        db = new SessionDatabaseHelper(this);

        // Starts activity
        setupActivity();
    }

    /**
     * Sets up the action bar.
     */
    @Override
    public boolean onCreateOptionsMenu(Menu menu)
    {
        // Inflates the menu, adding items to the action bar
        getMenuInflater().inflate(R.menu.toolbar_save, menu);
        return true;
    }

    /**
     * Called whenever an item in action bar is selected.
     */
    @Override
    public boolean onOptionsItemSelected(MenuItem item)
    {
        switch (item.getItemId())
        {
            // When clicking on saving a routine day
            case R.id.action_save:

                // Saves session
                saveSession();

                // Finishes activity and sends OK code to waiting activity
                Intent intent = new Intent();
                setResult(Utils.RESULT_OK, intent);
                finish();

                return true;

            default:
                return super.onOptionsItemSelected(item);
        }
    }

    /**
     * Displays initial data
     */
    private void setupActivity()
    {
        Settings settings = new SettingsDatabaseHelper(this).get();

        TextView summDate = findViewById(R.id.summDate);
        summDate.setText(Utils.formatDate(session.getStart(), "dd/MM/yyyy"));

        TextView summTime = findViewById(R.id.summTime);
        summTime.setText(Utils.formatTime(session.getStart(), session.getFinish()));

        distance = findViewById(R.id.distance);
        distance.setHint(getResources().getString(R.string.timed_distance) + " (" + settings.getDistanceUnit() + ")");
        speed = findViewById(R.id.speed);
        speed.setHint(getResources().getString(R.string.timed_speed) + " (" + settings.getDistanceUnit() + "/h)");
    }

    /**
     * Saves session into database
     */
    private void saveSession()
    {
        if (distance.getText() != null && !distance.getText().toString().isEmpty())
        {
            session.setDistance(Double.valueOf(distance.getText().toString().trim()));
        }

        if (speed.getText() != null && !speed.getText().toString().isEmpty())
        {
            session.setSpeed(Double.valueOf(speed.getText().toString().trim()));
        }

        db.update(session);
    }
}
