/*
 * Copyright (C) 2018 Pedro Perez
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package edu.uoc.sporttrack.adapter;

import android.support.v7.widget.RecyclerView;
import android.support.v7.widget.RecyclerView.ViewHolder;
import android.support.v7.widget.helper.ItemTouchHelper.SimpleCallback;

/**
 * An implementation of {@link android.support.v7.widget.helper.ItemTouchHelper.SimpleCallback}
 * that overrides methods to help with the drag and drop.
 */
public class DragHelper extends SimpleCallback
{
    private OnItemActionListener listener;

    public DragHelper(int dragDirs, int swipeDirs, OnItemActionListener listener)
    {
        super(dragDirs, swipeDirs);
        this.listener = listener;
    }

    /**
     * Callback when item is being moved and notifies the listener of the move. It overrides {@link
     * android.support.v7.widget.helper.ItemTouchHelper.Callback#onMove(RecyclerView, ViewHolder, ViewHolder)}
     */
    @Override
    public boolean onMove(RecyclerView recyclerView, ViewHolder source, ViewHolder target)
    {
        if (source.getItemViewType() != target.getItemViewType())
        {
            return false;
        }

        // Notify the listener of the move
        listener.onItemMove(source.getAdapterPosition(), target.getAdapterPosition());
        return true;
    }

    /**
     * Callback when item is being swiped and notifies the listener of the dismissal. It overrides {@link
     * android.support.v7.widget.helper.ItemTouchHelper.Callback#onSwiped(ViewHolder, int)}}
     */
    @Override
    public void onSwiped(RecyclerView.ViewHolder viewHolder, int direction)
    {
        // Does nothing
    }

    /**
     * Called by the helper when the item has finished being moved. It overrides {@link
     * android.support.v7.widget.helper.ItemTouchHelper.Callback#clearView(RecyclerView, ViewHolder)}}
     */
    @Override
    public void clearView(RecyclerView recyclerView, RecyclerView.ViewHolder holder)
    {
        super.clearView(recyclerView, holder);
        listener.onItemMoved((RecyclerAdapter.ItemHolder) holder);
    }
}
