/*
 * Copyright (C) 2018 Pedro Perez
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package edu.uoc.sporttrack.adapter;

import edu.uoc.sporttrack.model.Itemizable;

/**
 * Interface to listen for action events in items in a recycler view.
 */
public interface OnItemActionListener
{
    /**
     * Callback when a item is to be selected
     *
     * @param item The item binded to the recycler view
     */
    void onItemSelect(Itemizable item);

    /**
     * Callback when a item is to be deleted
     *
     * @param item The item binded to the recycler view
     */
    void onItemDelete(Itemizable item);

    /**
     * Callback when a item is to be edited
     *
     * @param item The item binded to the recycler view
     */
    void onItemEdit(Itemizable item);

    /**
     * Callback when a item is to be dragged
     *
     * @param holder The view holder being dragged.
     */
    void onItemDrag(RecyclerAdapter.ItemHolder holder);

    /**
     * Callback when an item is dragged from one position to another.
     *
     * @param fromPosition The position in the adapter which is moving from.
     * @param toPosition   The position in the adapter which is moving to.
     */
    void onItemMove(int fromPosition, int toPosition);

    /**
     * Callback when an item is dragged from one position to another.
     *
     * @param holder The view holder that has just finished moving.
     */
    void onItemMoved(RecyclerAdapter.ItemHolder holder);

}
