/*
 * Copyright (C) 2018 Pedro Perez
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package edu.uoc.sporttrack.database;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;

import edu.uoc.sporttrack.model.Profile;
import edu.uoc.sporttrack.utils.Utils;

public class ProfileDatabaseHelper extends DatabaseHelper
{
    /**
     * Constructor
     */
    public ProfileDatabaseHelper(Context context)
    {
        super(context);
    }

    /**
     * Gets item from database
     */
    public Profile get()
    {
        Profile profile = null;

        // Opens database in read mode
        SQLiteDatabase db = this.getReadableDatabase();

        if (db == null)
        {
            return null;
        }

        String[] cols = new String[]{COL_NAME, COL_DOB, COL_GENDER, COL_HEIGHT, COL_WEIGHT};
        Cursor cursor = db.query(TAB_PROFILE, cols, null, null, null, null, null, null);

        // We ensure there is at least a record
        if (cursor.moveToNext())
        {
            profile = new Profile();
            profile.setName(cursor.getString(0));
            profile.setDob(Utils.getDate(cursor.getString(1)));
            profile.setGender(cursor.getInt(2));
            profile.setHeight(cursor.getDouble(3));
            profile.setWeight(cursor.getDouble(4));
        }

        // Closing cursor and database connection
        cursor.close();
        db.close();

        // return profile
        return profile;
    }

    /**
     * Updates item into database
     */
    public long update(Profile profile)
    {
        // Opens database in write mode
        SQLiteDatabase db = this.getWritableDatabase();

        long result = 0;

        if (db == null)
        {
            return result;
        }

        // Retrieves values to commit
        ContentValues values = new ContentValues();
        values.put(COL_NAME, profile.getName());
        values.put(COL_DOB, Utils.formatDate(profile.getDob(), null));
        values.put(COL_GENDER, profile.getGender());
        values.put(COL_HEIGHT, profile.getHeight());
        values.put(COL_WEIGHT, profile.getWeight());

        String[] cols = new String[]{COL_NAME, COL_DOB, COL_GENDER, COL_HEIGHT, COL_WEIGHT};
        Cursor cursor = db.query(TAB_PROFILE, cols, null, null, null, null, null, null);

        // We ensure there is at least a record
        if (cursor.moveToFirst())
        {
            // Updating row
            result = db.update(TAB_PROFILE, values, null, null);
        }
        else
        {
            // Inserting row
            result = db.insert(TAB_PROFILE, null, values);
        }

        // Closing cursor and database connection
        cursor.close();
        db.close();

        return result;
    }

}