/*
 * Copyright (C) 2018 Pedro Perez
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package edu.uoc.sporttrack.database;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;

import edu.uoc.sporttrack.model.Settings;

public class SettingsDatabaseHelper extends DatabaseHelper
{
    /**
     * Constructor
     */
    public SettingsDatabaseHelper(Context context)
    {
        super(context);
    }

    /**
     * Gets item from database
     */
    public Settings get()
    {
        Settings settings = null;

        // Opens database in read mode
        SQLiteDatabase db = this.getReadableDatabase();

        if (db == null)
        {
            return null;
        }

        String[] cols = new String[]{COL_DIST, COL_WEIGHT, COL_HEIGHT, COL_SETS, COL_REPS, COL_REST};
        Cursor cursor = db.query(TAB_SETTS, cols, null, null, null, null, null, null);

        // We ensure there is at least a record
        if (cursor.moveToNext())
        {
            settings = new Settings();

            settings.setDistanceUnit(cursor.getString(0));
            settings.setWeightUnit(cursor.getString(1));
            settings.setHeightUnit(cursor.getString(2));
            settings.setSets(cursor.getInt(3));
            settings.setReps(cursor.getInt(4));
            settings.setRest(cursor.getInt(5));
        }

        // Closing cursor and database connection
        cursor.close();
        db.close();

        // return settings
        return settings;
    }

    /**
     * Updates item into database
     */
    public long update(Settings settings)
    {
        // Opens database in write mode
        SQLiteDatabase db = this.getWritableDatabase();

        long result = 0;

        if (db == null)
        {
            return result;
        }

        // Retrieves values to commit
        ContentValues values = new ContentValues();
        values.put(COL_DIST, settings.getDistanceUnit());
        values.put(COL_HEIGHT, settings.getHeightUnit());
        values.put(COL_WEIGHT, settings.getWeightUnit());
        values.put(COL_SETS, settings.getSets());
        values.put(COL_REPS, settings.getReps());
        values.put(COL_REST, settings.getRest());

        // Updating row
        result = db.update(TAB_SETTS, values, null, null);

        // Closing database connection
        db.close();

        return result;
    }

}