/*
 * Copyright (C) 2018 Pedro Perez
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package edu.uoc.sporttrack.model;

import android.os.Parcel;
import android.os.Parcelable;

import java.util.Date;

import edu.uoc.sporttrack.R;
import edu.uoc.sporttrack.utils.Utils;

public class Day extends Base implements Parcelable
{
    private long id;
    private int position;
    private String name;
    private long idRoutine;
    private Date lastLogged;
    private int numPlans;

    public Day()
    {
    }

    public Day(Parcel parcel)
    {
        id = parcel.readLong();
        position = parcel.readInt();
        name = parcel.readString();
        idRoutine = parcel.readLong();
        lastLogged = (Date) parcel.readSerializable();
        numPlans = parcel.readInt();
    }

    public long getId()
    {
        return id;
    }

    public void setId(long id)
    {
        this.id = id;
    }

    public String getName()
    {
        return name;
    }

    public void setName(String name)
    {
        this.name = name;
    }

    public int getPosition()
    {
        return position;
    }

    public void setPosition(int position)
    {
        this.position = position;
    }

    public long getIdRoutine()
    {
        return idRoutine;
    }

    public void setIdRoutine(long idRoutine)
    {
        this.idRoutine = idRoutine;
    }

    public void setNumPlans(int numPlans)
    {
        this.numPlans = numPlans;
    }

    public int getNumPlans()
    {
        return numPlans;
    }

    public Date getLastLogged()
    {
        return lastLogged;
    }

    public void setLastLogged(Date lastLogged)
    {
        this.lastLogged = lastLogged;
    }

    @Override
    public int describeContents()
    {
        return 0;
    }

    @Override
    public void writeToParcel(Parcel parcel, int i)
    {
        parcel.writeLong(id);
        parcel.writeInt(position);
        parcel.writeString(name);
        parcel.writeLong(idRoutine);
        parcel.writeSerializable(lastLogged);
        parcel.writeInt(numPlans);
    }

    // This is to de-serialize the object
    public static final Creator<Day> CREATOR = new Creator<Day>()
    {
        public Day createFromParcel(Parcel in)
        {
            return new Day(in);
        }

        public Day[] newArray(int size)
        {
            return new Day[size];
        }
    };

    @Override
    public String getItemTitle()
    {
        return String.format("%s %s: %s", context.getString(R.string.day_day), position, name);
    }

    @Override
    public String getItemSubtitle()
    {
        return numPlans > 0 ? String.format("%s: %s", context.getString(R.string.routine_exercises), numPlans) : String
                .format("%s", context.getString(R.string.routine_no_exercises));
    }

    @Override
    public String getItemRemark()
    {
        return lastLogged != null ? String
                .format("%s: %s", context.getString(R.string.workout_last), Utils.formatDate(lastLogged, "dd/MM/yyyy")) : context
                .getString(R.string.workout_no_trained);
    }

    @Override
    public boolean isEditable()
    {
        return true;
    }

    @Override
    public boolean isDeletable()
    {
        return true;
    }

}
