/*
 * Copyright (C) 2018 Pedro Perez
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package edu.uoc.sporttrack.model;

import android.os.Parcel;
import android.os.Parcelable;

public class Exercise extends Base implements Parcelable, Itemizable
{
    private long id;
    private long idBodypart;
    private boolean builtIn;
    private String name;
    private String description;
    private boolean selectionMode;
    private String type;

    public Exercise()
    {
        this.builtIn = false;
        this.selectionMode = false;
    }

    public long getId()
    {
        return id;
    }

    public void setId(long id)
    {
        this.id = id;
    }

    public long getIdBodypart()
    {
        return idBodypart;
    }

    public void setIdBodypart(long idBodypart)
    {
        this.idBodypart = idBodypart;
    }

    public boolean isBuiltIn()
    {
        return builtIn;
    }

    public void setBuiltIn(boolean builtIn)
    {
        this.builtIn = builtIn;
    }

    public String getName()
    {
        return name;
    }

    public void setName(String name)
    {
        this.name = name;
    }

    public String getDescription()
    {
        return description;
    }

    public void setDescription(String description)
    {
        this.description = description;
    }

    public void setSelectionMode(boolean selectionMode)
    {
        this.selectionMode = selectionMode;
    }

    public void setType(String type)
    {
        this.type = type;
    }

    @Override
    public int describeContents()
    {
        return 0;
    }

    @Override
    public void writeToParcel(Parcel parcel, int i)
    {
        parcel.writeLong(id);
        parcel.writeLong(idBodypart);
        parcel.writeString(name);
        parcel.writeString(description);
        parcel.writeString(type);
        parcel.writeByte((byte) (builtIn ? 1 : 0));
        parcel.writeByte((byte) (selectionMode ? 1 : 0));
    }

    public Exercise(Parcel parcel)
    {
        id = parcel.readLong();
        idBodypart = parcel.readLong();
        name = parcel.readString();
        description = parcel.readString();
        type = parcel.readString();
        builtIn = parcel.readByte() != 0;
        selectionMode = parcel.readByte() != 0;
    }

    // This is to de-serialize the object
    public static final Parcelable.Creator<Exercise> CREATOR = new Parcelable.Creator<Exercise>()
    {
        public Exercise createFromParcel(Parcel in)
        {
            return new Exercise(in);
        }

        public Exercise[] newArray(int size)
        {
            return new Exercise[size];
        }
    };

    @Override
    public String getItemTitle()
    {
        return name;
    }

    @Override
    public String getItemSubtitle()
    {
        return type;
    }

    @Override
    public boolean isEditable()
    {
        return !builtIn && !selectionMode;
    }

    @Override
    public boolean isDeletable()
    {
        return !builtIn && !selectionMode;
    }

}
