/*
 * Copyright (C) 2018 Pedro Perez
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package edu.uoc.sporttrack.model;

import android.os.Parcel;
import android.os.Parcelable;

public class Plan extends Base implements Parcelable, Itemizable
{
    private long id;
    private long idDay;
    private long idExercise;
    private String exerciseName;
    private String bodypart;
    private int position;
    private int sets;
    private int reps;
    private int rest;

    public Plan()
    {
    }

    public long getId()
    {
        return id;
    }

    public void setId(long id)
    {
        this.id = id;
    }

    public long getIdDay()
    {
        return idDay;
    }

    public void setIdDay(long idDay)
    {
        this.idDay = idDay;
    }

    public long getIdExercise()
    {
        return idExercise;
    }

    public void setIdExercise(long idExercise)
    {
        this.idExercise = idExercise;
    }

    public String getExerciseName()
    {
        return exerciseName;
    }

    public String getBodypart()
    {
        return bodypart;
    }

    public void setExerciseName(String exerciseName)
    {
        this.exerciseName = exerciseName;
    }

    public void setBodypart(String bodypart)
    {
        this.bodypart = bodypart;
    }

    public int getSets()
    {
        return sets;
    }

    public void setSets(int sets)
    {
        this.sets = sets;
    }

    public int getReps()
    {
        return reps;
    }

    public void setReps(int reps)
    {
        this.reps = reps;
    }

    public int getRest()
    {
        return rest;
    }

    public void setRest(int rest)
    {
        this.rest = rest;
    }

    public int getPosition()
    {
        return position;
    }

    public void setPosition(int position)
    {
        this.position = position;
    }

    public Plan(Parcel parcel)
    {
        id = parcel.readLong();
        idDay = parcel.readLong();
        idExercise = parcel.readLong();
        exerciseName = parcel.readString();
        bodypart = parcel.readString();
        position = parcel.readInt();
        sets = parcel.readInt();
        reps = parcel.readInt();
        rest = parcel.readInt();
    }

    @Override
    public int describeContents()
    {
        return 0;
    }

    @Override
    public void writeToParcel(Parcel parcel, int i)
    {
        parcel.writeLong(id);
        parcel.writeLong(idDay);
        parcel.writeLong(idExercise);
        parcel.writeString(exerciseName);
        parcel.writeString(bodypart);
        parcel.writeInt(position);
        parcel.writeInt(sets);
        parcel.writeInt(reps);
        parcel.writeInt(rest);
    }

    // This is to de-serialize the object
    public static final Parcelable.Creator<Plan> CREATOR = new Parcelable.Creator<Plan>()
    {
        public Plan createFromParcel(Parcel in)
        {
            return new Plan(in);
        }

        public Plan[] newArray(int size)
        {
            return new Plan[size];
        }
    };

    @Override
    public String getItemTitle()
    {
        return exerciseName;
    }

    @Override
    public String getItemSubtitle()
    {
        return bodypart;
    }

    @Override
    public String getItemSets()
    {
        return String.valueOf(sets);
    }

    @Override
    public String getItemReps()
    {
        return String.valueOf(reps);
    }

    @Override
    public String getItemRest()
    {
        return String.valueOf(rest);
    }

    @Override
    public boolean isEditable()
    {
        return true;
    }

    @Override
    public boolean isDeletable()
    {
        return true;
    }
}
