/*
 * Copyright (C) 2018 Pedro Perez
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package edu.uoc.sporttrack.model;

import android.os.Parcel;
import android.os.Parcelable;

import edu.uoc.sporttrack.R;

public class Routine extends Base implements Parcelable, Itemizable
{
    private long id;
    private boolean current;
    private String name;
    private String description;
    private int numDays;

    public Routine()
    {
    }

    public Routine(Parcel parcel)
    {
        id = parcel.readLong();
        name = parcel.readString();
        description = parcel.readString();
        current = parcel.readByte() != 0;
        numDays = parcel.readInt();
    }

    public long getId()
    {
        return id;
    }

    public void setId(long id)
    {
        this.id = id;
    }

    public boolean isCurrent()
    {
        return current;
    }

    public void setCurrent(boolean current)
    {
        this.current = current;
    }

    public String getName()
    {
        return name;
    }

    public void setName(String name)
    {
        this.name = name;
    }

    public String getDescription()
    {
        return description;
    }

    public void setDescription(String description)
    {
        this.description = description;
    }

    public void setNumDays(int numDays)
    {
        this.numDays = numDays;
    }

    @Override
    public int describeContents()
    {
        return 0;
    }

    @Override
    public void writeToParcel(Parcel parcel, int i)
    {
        parcel.writeLong(id);
        parcel.writeString(name);
        parcel.writeString(description);
        parcel.writeByte((byte) (current ? 1 : 0));
        parcel.writeInt(numDays);
    }

    // This is to de-serialize the object
    public static final Creator<Routine> CREATOR = new Creator<Routine>()
    {
        public Routine createFromParcel(Parcel in)
        {
            return new Routine(in);
        }

        public Routine[] newArray(int size)
        {
            return new Routine[size];
        }
    };

    @Override
    public String getItemTitle()
    {
        return name;
    }

    @Override
    public String getItemSubtitle()
    {
        return numDays > 0 ? String.format("%s: %s", context.getString(R.string.routine_days), numDays) : String
                .format("%s", context.getString(R.string.routine_no_days));
    }

    @Override
    public boolean isHighlighted()
    {
        return current;
    }

    @Override
    public boolean isEditable()
    {
        return true;
    }

    @Override
    public boolean isDeletable()
    {
        return true;
    }
}
