/*
 * Copyright (C) 2018 Pedro Perez
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package edu.uoc.sporttrack.model;

import android.os.Parcel;
import android.os.Parcelable;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import edu.uoc.sporttrack.R;
import edu.uoc.sporttrack.utils.Utils;

public class Session extends Base implements Parcelable
{
    private long id;
    private long idSport;
    private Date start;
    private Date finish;
    private long idDay;
    private String dayName;
    private double speed;
    private double distance;
    private String unit;
    private double calories;
    private List<LogPlan> logPlans;

    public Session()
    {
        logPlans = new ArrayList<>();
    }

    public Session(Parcel parcel)
    {
        id = parcel.readLong();
        idSport = parcel.readLong();
        start = (Date) parcel.readSerializable();
        finish = (Date) parcel.readSerializable();
        idDay = parcel.readLong();
        dayName = parcel.readString();
        speed = parcel.readDouble();
        distance = parcel.readDouble();
        unit = parcel.readString();
        calories = parcel.readDouble();
    }

    @Override
    public long getId()
    {
        return id;
    }

    public void setId(long id)
    {
        this.id = id;
    }

    public long getIdDay()
    {
        return idDay;
    }

    public void setIdDay(long idDay)
    {
        this.idDay = idDay;
    }

    public String getDayName()
    {
        return dayName;
    }

    public void setDayName(String dayName)
    {
        this.dayName = dayName;
    }

    public Date getStart()
    {
        return start;
    }

    public void setStart(Date start)
    {
        this.start = start;
    }

    public Date getFinish()
    {
        return finish;
    }

    public void setFinish(Date finish)
    {
        this.finish = finish;
    }

    public List<LogPlan> getLogPlans()
    {
        return logPlans;
    }

    public void setLogPlans(List<LogPlan> logPlans)
    {
        this.logPlans = logPlans;
    }

    public long getIdSport()
    {
        return idSport;
    }

    public void setIdSport(long idSport)
    {
        this.idSport = idSport;
    }

    public double getSpeed()
    {
        return speed;
    }

    public void setSpeed(double speed)
    {
        this.speed = speed;
    }

    public double getDistance()
    {
        return distance;
    }

    public void setDistance(double distance)
    {
        this.distance = distance;
    }

    public String getUnit()
    {
        return unit;
    }

    public void setUnit(String unit)
    {
        this.unit = unit;
    }

    public double getCalories()
    {
        return calories;
    }

    public void setCalories(double calories)
    {
        this.calories = calories;
    }

    @Override
    public int describeContents()
    {
        return 0;
    }

    @Override
    public void writeToParcel(Parcel parcel, int i)
    {
        parcel.writeLong(id);
        parcel.writeLong(idSport);
        parcel.writeSerializable(start);
        parcel.writeSerializable(finish);
        parcel.writeLong(idDay);
        parcel.writeString(dayName);
        parcel.writeDouble(speed);
        parcel.writeDouble(distance);
        parcel.writeString(unit);
        parcel.writeDouble(calories);
    }

    // This is to de-serialize the object
    public static final Creator<Session> CREATOR = new Creator<Session>()
    {
        public Session createFromParcel(Parcel in)
        {
            return new Session(in);
        }

        public Session[] newArray(int size)
        {
            return new Session[size];
        }
    };

    @Override
    public String getItemTitle()
    {
        if (idSport == Utils.SPORT_WORKOUT)
        {
            return dayName;
        }
        else
        {
            String result = "";

            if (distance != 0)
            {
                result += Utils.formatNumber(distance) + " " + unit;
            }

            if (finish != null)
            {
                if (result.length() > 0)
                {
                    result = result + " | ";
                }
                result = result + Utils.formatTime(start, finish);
            }

            if (speed != 0)
            {
                if (result.length() > 0)
                {
                    result = result + " | ";
                }
                result = result + Utils.formatNumber(speed) + " " + unit + "/h";
            }

            return result;
        }
    }

    @Override
    public String getItemSubtitle()
    {
        String result = Utils.formatDate(start, "HH:mm");
        if (finish != null)
        {
            result = result + " - " + Utils.formatDate(finish, "HH:mm");
        }

        return result;
    }

    @Override
    public String getItemRemark()
    {
        String[] sports = context.getResources().getStringArray(R.array.sports);
        return sports[(int) idSport - 1];

    }

    @Override
    public boolean isSelectable()
    {
        return idSport != Utils.SPORT_TIMED;
    }
}
