/*
 * Copyright (C) 2018 Pedro Perez
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package edu.uoc.sporttrack.model;

import java.util.Date;

import edu.uoc.sporttrack.utils.Utils;

public class WorkoutDay extends Base
{
    private long id;
    private String exercise;
    private String bodypart;
    private Double weight;
    private String weightUnit;
    private int reps;
    private int rest;
    private Date logDate;

    public WorkoutDay()
    {
    }

    public long getId()
    {
        return id;
    }

    public void setId(long id)
    {
        this.id = id;
    }

    public String getExercise()
    {
        return exercise;
    }

    public void setExercise(String exercise)
    {
        this.exercise = exercise;
    }

    public String getBodypart()
    {
        return bodypart;
    }

    public void setBodypart(String bodypart)
    {
        this.bodypart = bodypart;
    }

    public Double getWeight()
    {
        return weight;
    }

    public void setWeight(Double weight)
    {
        this.weight = weight;
    }

    public void setWeightUnit(String weightUnit)
    {
        this.weightUnit = weightUnit;
    }

    public void setLogDate(Date logDate)
    {
        this.logDate = logDate;
    }

    public int getReps()
    {
        return reps;
    }

    public void setReps(int reps)
    {
        this.reps = reps;
    }

    public int getRest()
    {
        return rest;
    }

    public void setRest(int rest)
    {
        this.rest = rest;
    }

    @Override
    public String getItemTitle()
    {
        return exercise;
    }

    @Override
    public String getItemSubtitle()
    {
        return bodypart;
    }

    @Override
    public String getItemRemark()
    {
        return Utils.formatDate(logDate, "HH:mm");
    }

    @Override
    public String getItemReps()
    {
        return String.valueOf(reps);
    }

    @Override
    public String getItemRest()
    {
        return String.valueOf(rest);
    }

    @Override
    public String getItemWeight()
    {
        return Utils.formatNumber(weight) + " " + weightUnit;
    }

    @Override
    public boolean isSelectable()
    {
        return false;
    }
}
